
# Jocular

Jocular is a tool for **Electronically-Assisted Visual Astronomy** (EEVA).

Jocular supports the observation of astronomical objects in near real-time by connecting up a camera to a telescope or suitable lens. It also supports session-planning through extensive deep sky object (DSO) databases, helps to manage your captures, and
enables the reloading of previously-captured images.

Please visit the <a href="https://transpy.eu.pythonanywhere.com/jocular/">Jocular</a> web page for more information.

